/* ETL/etl_profile_.h.  Generated from etl_profile_.h.in by configure.  */
/* ETL/etl_profile_.h.in.  Generated from configure.ac by autoheader.  */


// We want to be autoconf/autoheader friendly, so
// if the developer has already included an
// autoheader-generated configuration script,
// we can assume that the user knew what they
// were doing and let them use their own config.h.
//#ifndef ETL_TARNAME


/* define if the compiler supports basic C++11 syntax */
/* #undef HAVE_CXX11 */

/* Define to 1 if you have the `gettimeofday' function. */
#define HAVE_GETTIMEOFDAY 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the `user32' library (-luser32). */
/* #undef HAVE_LIBUSER32 */

/* Define to 1 if you have the `QueryPerformanceCounter' function. */
/* #undef HAVE_QUERYPERFORMANCECOUNTER */

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdio.h> header file. */
#define HAVE_STDIO_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define to 1 if you have the <windows.h> header file. */
/* #undef HAVE_WINDOWS_H */

/* Define to the address where bug reports for this package should be sent. */
#define ETL_BUGREPORT "https://github.com/synfig/synfig/issues"

/* Define to the full name of this package. */
#define ETL_NAME "Extended Template Library"

/* Define to the full name and version of this package. */
#define ETL_STRING "Extended Template Library 1.5.3"

/* Define to the one symbol short name of this package. */
#define ETL_TARNAME "ETL"

/* Define to the home page for this package. */
#define ETL_URL ""

/* Define to the version of this package. */
#define ETL_VERSION "1.5.3"

/* Define to 1 if all of the C90 standard headers exist (not just the ones
   required in a freestanding environment). This macro is provided for
   backward compatibility; new code need not use it. */
#define STDC_HEADERS 1


//#endif // ifndef ETL_TARNAME

